===================
Releasing a version
===================

The following guides include detailed information on how to prepare a NumPy
release. 

.. _prepare_release:

------------------------
How to prepare a release
------------------------

.. include:: ../../HOWTO_RELEASE.rst

-----------------------
Step-by-step directions
-----------------------

.. include:: ../../RELEASE_WALKTHROUGH.rst

.. _branching:

------------------
Branch walkthrough
------------------

.. include:: ../../BRANCH_WALKTHROUGH.rst